@@ -8,7 +8,7 @@ logger = logging.getLogger()
 logging.getLogger('calcbench').setLevel(logging.DEBUG)
 logger.addHandler(logging.StreamHandler(stream=sys.stdout))
 """
-__version__ = "3.3.0"
+__version__ = "4.0.1"
 from .api_client import (
     CompanyIdentifierScheme,
     as_reported_raw,
@@ -26,7 +26,7 @@ from .api_client import (
     tag_contents,
 )
 
-from .disclosures import document_search
+from .disclosures import document_search, document_dataframe
 from .companies import tickers, companies, companies_raw
 from .listener import handle_filings
 from .filing import filings, Filing
@@ -39,6 +39,6 @@ from .standardized_numeric import (
     standardized_data,
 )
 
-from .raw_numeric_XBRL import raw_data, raw_data_raw, raw_xbrl, raw_xbrl_raw
+from .raw_numeric_XBRL import raw_XBRL, raw_xbrl_raw
 
 from .raw_numeric_non_XBRL import non_XBRL_numeric_raw, non_XBRL_numeric
