@@ -134,6 +134,18 @@ def normalized_raw(
         raise ValueError(
             "Must pass either company_identifiers and accession id or entire_universe=True"
         )
+    if not any(
+        [
+            start_year,
+            end_year,
+            update_date,
+            year,
+            accession_id,
+            all_history,
+            period_type,
+        ]
+    ):
+        raise ValueError("Need to specify a period qualifier")
 
     if accession_id and any(
         [
@@ -299,7 +311,10 @@ def point_in_time(
 
 
     Usage::
-       >>> calcbench.point_in_time(company_identifiers=["msft", "goog"], all_history=True, all_face=True, all_footnotes=True)
+       >>> calcbench.point_in_time(company_identifiers=["msft", "goog"],
+       >>>                          all_history=True,
+       >>>                          all_face=True,
+       >>>                          all_footnotes=True)
 
     .. _Example: https://github.com/calcbench/notebooks/blob/master/standardized_numeric_point_in_time.ipynb
 
@@ -396,7 +411,13 @@ def normalized_dataframe(
 
     Usage::
 
-      >>> calcbench.standardized_data(company_identifiers=['msft', 'goog'], metrics=['revenue', 'assets'], all_history=True, period_type='annual')
+      >>> d = calcbench.standardized_data(company_identifiers=['msft', 'goog'],
+      >>>                                 metrics=['revenue', 'assets'],
+      >>>                                 all_history=True,
+      >>>                                 period_type='annual')
+
+      >>> # Make it look like Compustat data
+      >>> d.stack(level=1)
 
     """
 
